
*******************************************************************
* Construct Bank Balance Sheet Data Set from Call Reports and Y9C *
*******************************************************************

set more off
pause on 

* Connect to Server
odbc query "mssnarips.frb.gov", verbose

global root 	= "C:\Users\l1pxp07\Dropbox (FRB SF)\Pascal.Paul\Current Projects\Banks\Data\Bank Balance Sheet Data"
global bank_sp  = "C:\Users\l1pxp07\Dropbox (FRB SF)\Pascal.Paul\Current Projects\Banks\Data\Stock Prices"

global output 	= "$root/output"
global input  	= "$root/input"
global temp 	= "$root/tempfiles"
global aux 		= "$root/auxfiles"

**********************
** Choose Functions **
**********************

** Do-Files **

* Set to 1 to update pulls from Call Reports and Y9C
global pull_call_reports_Y9C 			0
* Aggregation: Set to 1 to aggregate all data to BHCs, 2 to commercial banks
global aggregate_to_bank_holding 		1
* Set to 1 to compute variables and save output
global compute_vars_and_save 			1
* Set to 1 to compute net interest margins (domestic), 2: domestic and foreign 
global compute_margins 					1

** Data **

* Set start date
global start_date 						19591231
* Set end date
global end_date 						20221231
* Choose Aggregation method (UNRESTRICED or RESTRICTED)
global method = 						"UNRESTRICTED"

** Adjustments to sample **

* Ratio of sum(total assets call reports)/Y9C above which to keep
global cutoff_total_assets_CR_Y9C 		0.95
* Cutoff level for loans/assets below which to drop
global cutoff_loans_assets 				0.25
* Drop observations without full data coverage for balance sheet items (restricting to >=1986Q1)
global only_non_missing_balance_sheet 	0
* Drop observations without full data coverage for maturity data (restricting to >=1997Q2)
global only_non_missing_maturity	 	0
* Drop 1st and 99th percentiles for maturity gap
global drop_extreme_mat_gap 			0
* Drop 1st and 99th percentiles for market leverage
global drop_extreme_market_lev 			0
* Drop observations with asset growth >20% & -20%
global drop_asset_growth 				0
* Drop observations with few observations
global drop_few_observations 			0

******************
** Run Do-Files **
******************

* Pull variables from Call Reports and Y9C and merge to combined data sets
if $pull_call_reports_Y9C == 1 {
	do "$aux/Pull_data_and_merge.do"
}
* Aggregate to BHCs
if $aggregate_to_bank_holding == 1 {
	do "$aux/Aggregate_to_BHCs.do"
}
else if $aggregate_to_bank_holding == 2 {
	do "$aux/Aggregate_to_CBs.do"
}
* Compute variables and save output
if $compute_vars_and_save == 1 {
	do "$aux/Compute_variables_and_save.do"
}
* Compute net interest margins
if $compute_margins >= 1 {
	do "$aux/Compute_margins.do"
}