
************** - Creating BHC to Subsidiary Mapping - **************************

cd "$input"

*************************************************************
** STEP 1 Merge BHC's to all Commercial Banks with Mapping **
*************************************************************

*Load in all Financial Institutions with Permco's
import delimited using "List of Banks.csv", clear
duplicates drop v4, force
duplicates drop v5, force

*Identify BHC and Commercial Banks
gen id_rssd_bhc = v4 	if v3 == "Bank Holding Company" | v3 == "Bank holding company"
gen id_rssd = v4 		if v3 != "Bank Holding Company" & v3 != "Bank holding company"

*clean up
drop in 1/2
rename v5 permco
rename v3 bank_type
drop v2
destring permco id_rssd_bhc id_rssd, replace force

*Merge in BHC to Commercial Mapping (ONLY FOR THE BHC's)
preserve
	drop if id_rssd_bhc==.
	drop id_rssd
	*Merge id_rssd_bhc with their mappings and only keep those that matched
	merge 1:m id_rssd_bhc using "$temp/other/raw_mapping.dta"
	keep if _merge==3
	drop _merge
	tempfile first
	save `first'
restore

*Append that mapping onto our Commercials
drop if id_rssd == .
*Merge id_rssd_bhc with their mappings and only keep those that matched
append using `first'

*Keep only the variables of interest
keep id_rssd_bhc id_rssd dt_start dt_end permco bank_type

replace dt_start 	= $start_date 	if id_rssd_bhc==.
replace dt_end 		= $end_date 	if id_rssd_bhc==.

sort id_rssd_bhc
sort id_rssd

*Fix dates formats
tostring dt_start, replace
tostring dt_end, replace
gen date_start 	= qofd(date(dt_start,"YMD"))
gen date_end 	= qofd(date(dt_end,"YMD"))
drop dt_start dt_end
format date_start date_end %tq

*Tag Multiple Start-End Relationships
bysort id_rssd id_rssd_bhc: gen tag = _n

*Append date end ontop of date_start and call it the date column
preserve
	keep id_rssd id_rssd_bhc date_start tag permco bank_type
	rename date_start date
	tempfile start
	save `start'
restore

keep id_rssd id_rssd_bhc date_end tag permco bank_type
rename date_end date
append using `start'

*To save memory when filling replace 9999 years with current date
replace date = qofd(date("$S_DATE", "DMY")) if year(dofq(date))==9999

sort id_rssd date

*Create Groups that represent episodes of relationships
egen group = group(id_rssd_bhc id_rssd tag), missing

*Within each relationship, marker denotes start and end with ones and two's
sort group date
by group: gen marker=_n

*Some relationships only exist for one quarter, tag and delete them
duplicates tag group date, gen(dont_delete)
duplicates drop group date, force

*Fill in gaps in dates
tsset group date
tsfill, full

*Control for those groupings that only have 1 date
replace marker = 2 if dont_delete == 1

*Mark the end points of the relationship between BHC's and Commercials 'dont_delete'
replace dont_delete = 1 if dont_delete == 0

*Control for Commercials who dont have BHC's
replace id_rssd_bhc = -9999 if id_rssd_bhc==. & id_rssd!=.

*Carryforward uses the most recent observation and fills in gaps until that observation changes
*Marker equals 1 and 2 for start and ends of relationships, we carry forward the 1's and keep those
*as well as the first 2 which denotes the end point of a relationship
carryforward marker, gen(mark2)
keep if mark2==1 | dont_delete == 1
carryforward id_rssd_bhc, gen(id_rssd_bhc2)
carryforward id_rssd, gen(id_rssd2)
carryforward permco, gen(permco2)
carryforward bank_type, gen(bank_type2)
drop id_rssd_bhc id_rssd permco bank_type
rename id_rssd2 id_rssd
rename id_rssd_bhc2 id_rssd_bhc
rename permco2 permco
rename bank_type2 bank_type

keep id_rssd id_rssd_bhc date permco bank_type
sort id_rssd_bhc date

*Replace the -9999's we created
replace id_rssd_bhc = . if id_rssd_bhc==-9999

duplicates drop id_rssd id_rssd_bhc date, force

tempfile refined_mapping
save `refined_mapping'

********************************************
** STEP 2 : Merge in Raw Call Report Data **
********************************************

cd "$output"

*Load in FFEIC 031 Commercial Banks Data
use call_data.dta, clear

*Fix dates
gen q_date = qofd(dofc(d_dt))
gen d_date = dofc(d_dt)
order q_date d_date
bysort q_date id_rssd: egen max_d_date = max(d_date)
order q_date d_date max_d_date
keep if max_d_date == d_date
drop max_d_date d_date
rename q_date date

*Merge the commercial banks id_rssd with the refined_mapping
*We are using one too many since a commercial bank can be associated to different BHCs
merge 1:m id_rssd date using `refined_mapping'
keep if _merge==3
drop _merge

** Clean Call Report Data
* Drop negative book equity banks
drop if RCONG105 < 0

* Drop observations with small loan share
drop if RCON2170==. | RCON2170==0
gen loan_share = RCON2122/RCON2170
drop if loan_share < $cutoff_loans_assets
drop loan_share

*This file includes all call report data
tempfile call_report_mapped
save `call_report_mapped'

***********************************
** STEP 3 : Load in Raw Y9C Data **
***********************************

*Use BHC data
use bhc_data, clear

*Clean Dating
gen date = qofd(dofc(d_dt))
drop d_dt
format date %tq

*Merge in the BHC's Total Assets, use one to many since BHCs appear multiple times
*for each date because of the multiple relationships
merge 1:m id_rssd_bhc date using `call_report_mapped'
drop if _merge==1
drop _merge

if $only_non_missing_balance_sheet == 1 {

	* Full coverage for assets, liabilities, loans, savings deposits, time deposits < 100k, demand & transaction deposits
	local varlist_missing RCON2170 RCON2948 RCON2122 RCON6810 RCON0352 RCON6648 RCON2215
	
	foreach var in `varlist_missing' {
		drop if `var' == .
	}
	
}

if $only_non_missing_maturity == 1 {

	* Maturity data for assets
	forvalues i = 49/62 {
		drop if RCONA5`i' == .
	}
	forvalues i = 64/75 {
		drop if RCONA5`i' == .
	}
	
	* Maturity data for liabilities
	gen mat_liab_all_2016 	= RCONA584 + RCONA585 + RCONA586 + RCONA587 + RCONA579 + RCONA580 + RCONA581 + RCONA582
	gen mat_liab_all_2017 	= RCONHK12 + RCONHK13 + RCONHK14 + RCONHK15 + RCONHK07 + RCONHK08 + RCONHK09 + RCONHK10
	
	gen mat_liab_all 		= mat_liab_all_2016
	replace mat_liab_all 	= mat_liab_all_2017 if date>=228 // 2017Q1 or after
	drop if mat_liab_all 	== .
	drop if mat_liab_all_2016 == 0 & date < 228  // before 2017Q1
	drop if mat_liab_all_2017 == 0 & date >= 228 // 2017Q1 or after
	
	drop mat_liab_all_2016 mat_liab_all_2017 mat_liab_all

}

*sort and drop
order id_rssd id_rssd_bhc date BHCK2170 RCON2170 
sort id_rssd_bhc d_dt

tempfile final
save `final'

************************************************************
** STEP 4: Keep BHCs for which the aggregation works well **
************************************************************

* Drop non-BHCs for now, added back below
drop if id_rssd_bhc == .

* Sum the commercial banks assets
collapse BHCK2170 (sum) RCON2170, by(id_rssd_bhc date)

* Drop BHCs that are missings in total assets
drop if BHCK2170 == . | BHCK2170 == 0

* Keep only BHC's whose total assets are close to the summation of the total assets
* of the commercial banks we mapped (by date and BHC)
gen close = RCON2170/BHCK2170
keep if close>$cutoff_total_assets_CR_Y9C

keep id_rssd_bhc date
tempfile bhc_list
save `bhc_list'

use `final', clear
merge m:1 id_rssd_bhc date using `bhc_list'

* Keep BHCs that aggregated well or the observation is from our master_dataset and didn't have a BHC mapping. 
keep if _merge==3 | id_rssd_bhc==.
drop _merge

* Clean Y9C data
	* Negative observation for maturity data
drop if BHCK3409 < 0

* Aggregate BHC's
	* Collapse treats missings as zeros when summing
	* Collapse ignores missings when averaging
	
preserve
	collapse (sum) RCON* (mean) BHCK* (sum) RIAD* (sum) RCFD* (first) permco bank_type if id_rssd_bhc!=., by(date id_rssd_bhc)
	tempfile aggregate
	save `aggregate'
restore

keep if id_rssd_bhc==.

append using `aggregate'

* Small loan share
gen loan_share = RCON2122/RCON2170
drop if loan_share < $cutoff_loans_assets
drop loan_share

tempfile data_set_me
save `data_set_me'

* Compute Market Leverage

insheet using "$bank_sp\Bank_level_data_volume.csv", clear

gen date2 = date(date,"MDY")
gen dq = qofd(date2)
format dq %tq
drop date date2
rename dq date
	
drop if prc <= 0

bysort permco date: gen count_sn = _n
bysort permco date: gen count_ln = _N

keep if count_sn == count_ln

duplicates report date permco

gen market_equity = shrout*prc

keep permco date market_equity

tempfile Bank_level_stocks
save `Bank_level_stocks'
use `data_set_me', clear
merge 1:1 permco date using `Bank_level_stocks'
drop if _merge == 2
drop _merge

gen market_lev 			= (market_equity + RCON2948)/market_equity
label var market_lev 	"Market Leverage, (Market Equity + Liabilities)/Market Equity"

save "$temp/other/aggregated_to_BHCs.dta", replace
