
if $aggregate_to_bank_holding == 2 {
	use "$temp/other/CBs_only.dta", clear
}
else if "$method"=="RESTRICTED" {
	use "$output/master_data_restricted_NIM.dta", clear
	drop if bank_type == "Commercial Bank"
	drop if bank_type == "Thrift holding company"
}
else if "$method"=="UNRESTRICTED" {
	use "$output/master_data_unrestricted_NIM.dta", clear
	drop if bank_type == "Commercial Bank"
	drop if bank_type == "Thrift holding company"
}

*****************************************
* Annualize data
*****************************************

local all_income 	= "RIAD4230 RIADJJ33 RIAD4135 RIAD4092 RIADC216 RIADC232 RIAD4531"
local foreign 		= "RIADC899 RIADC900 RIADB525 RIAD4842 RIADC914 RIAD4341 RIADC902 RIADC903 RIADC904 RIADC905 RIAD4097 RIADC907 RIAD4239 RIADC901 RIADKW02 RIAD4235"
local collect_miss  = "RIAD4340 RIAD4074 RIAD4079 RIAD4093 RIAD4107 RIAD4073"
local nonint_vars 	= "RIAD4070 RIAD4080 RIADA220 RIADC886 RIADC888 RIADC887 RIADC386 RIADC387 RIADB491 RIADB492 RIADB493 RIADB497 RIAD5416 RIAD5415 RIADB496"

** Difference from previous quarter, multiply by 4 to annualize
if $aggregate_to_bank_holding == 2 {
	tsset id_rssd date
	sort id_rssd date
}
else {
	tsset permco date
	sort permco date
}
foreach x in `collect_miss' {
	drop if missing(`x')
}
foreach i in `collect_miss' {
	gen `i'_a = `i' - L.`i'
	replace `i'_a = `i' if mod(date,4) == 0
	replace `i'_a = 4*`i'_a
}
foreach x in `collect_miss' {
	drop if missing(`x_a')
}
foreach i in `all_income' `foreign' `nonint_vars'{
	gen `i'_a = `i' - L.`i'
	replace `i'_a = `i' if mod(date,4) == 0
	replace `i'_a = 4*`i'_a
	replace `i'_a = 0 if `i'_a == .
}

*****************************************
* Construct Domestic Only
*****************************************

* Net Income
gen net_inc 			= RIAD4340_a - RIADC914_a 	if year >= 2006
replace net_inc 		= RIAD4340_a - RIAD4341_a 	if year <= 2005

* Net Interest Income
gen net_int_inc 		= RIAD4074_a - RIADC899_a + RIADC900_a 	if year >= 2006
replace net_int_inc 	= RIAD4074_a - RIADB525_a 				if year <= 2005 & year >= 2001
replace net_int_inc 	= RIAD4074_a - RIAD4842_a 				if year <= 2000

* Net Noninterest Income
gen nonint_inc 			= RIAD4079_a - RIADC902_a - RIADC903_a - RIADC904_a - RIADC905_a 	if year >= 2006
replace nonint_inc 		= RIAD4079_a - RIAD4097_a											if year <= 2005
gen nonint_exp  		= RIAD4093_a - RIADC907_a 											if year >= 2006
replace nonint_exp 		= RIAD4093_a - RIAD4239_a 											if year <= 2005
gen net_nonint_inc  	= nonint_inc - nonint_exp

* Provision for loan losses
gen other_provision 	= - RIAD4230_a		 				if year <= 2018
replace other_provision = - RIADJJ33_a 						if year >= 2019
replace other_provision = other_provision + RIADKW02_a 		if year >= 2019
replace other_provision = other_provision + RIADC901_a 		if year >= 2006 & year <= 2018
replace other_provision = other_provision + RIAD4235_a 		if year <= 2005

* Other Income
gen other_income 		= net_inc - net_int_inc - net_nonint_inc - other_provision

* Assets
gen totassets 			= RCON2170
gen avgearnassets 		= RCON0071 + RCON2122 
replace avgearnassets 	= avgearnassets + RCON0390 + RCON2146 				if year <= 1993
replace avgearnassets 	= avgearnassets + RCON3545 + RCON1754 + RCON1772    if year >= 1994
replace avgearnassets 	= avgearnassets + RCON1350 							if year <= 2001
replace avgearnassets 	= avgearnassets + RCONB987 + RCONB989 				if year >= 2002

*****************************************
* Construct Domestic + Foreign
*****************************************

gen f_net_inc 			= RIAD4340_a
gen f_net_int_inc 		= RIAD4074_a
gen f_nonint_inc 		= RIAD4079_a
gen f_nonint_exp 		= RIAD4093_a
gen f_net_nonint_inc  	= f_nonint_inc - f_nonint_exp
gen f_totassets 		= RCFD2170
gen f_int_inc 			= RIAD4107_a
gen f_int_exp 			= RIAD4073_a

*****************************************
* Output Excel for Figures
*****************************************

local vars 	= "net_inc net_int_inc nonint_inc nonint_exp net_nonint_inc other_provision other_income totassets f_net_inc f_totassets f_int_inc f_int_exp"

foreach x in `vars' {
	drop if missing(`x')
}

collapse (sum) net_* nonint_* other_* f_* totassets, by(date)

replace net_int_inc 		= 100*(net_int_inc/totassets)
replace nonint_inc 			= 100*(nonint_inc/totassets)
replace nonint_exp 			= 100*(nonint_exp/totassets)
replace net_nonint_inc 		= 100*(net_nonint_inc/totassets)
replace other_income 		= 100*(other_income/totassets)
replace other_provision 	= 100*(other_provision/totassets)
replace net_inc 			= 100*(net_inc/totassets)

replace f_net_inc 			= 100*(f_net_inc/f_totassets)
replace f_net_int_inc 		= 100*(f_net_int_inc/f_totassets)
replace f_nonint_inc 		= 100*(f_nonint_inc/f_totassets)
replace f_nonint_exp 		= 100*(f_nonint_exp/f_totassets)
replace f_net_nonint_inc 	= 100*(f_net_nonint_inc/f_totassets)
replace f_int_inc 			= 100*(f_int_inc/f_totassets)
replace f_int_exp 			= 100*(f_int_exp/f_totassets)

order date
export excel date net_int_inc nonint_inc nonint_exp net_nonint_inc other_income other_provision net_inc f_net_inc f_net_int_inc f_nonint_inc f_nonint_exp f_net_nonint_inc f_int_inc f_int_exp using "$output/Call_Reports_Income_data", sheet(sum) firstrow(variables) replace
