
use "$temp/other/aggregated_to_BHCs.dta", clear

**********************************
* STEP 5 : Compute Maturity Gap **
**********************************

gen year  = yofd(dofq(date))

* Interest-Earning Assets
gen int_earn_assets 	= 	RCON0071 + RCON2122 
replace int_earn_assets = 	int_earn_assets + RCON0390 + RCON2146 				if year < 1994
replace int_earn_assets = 	int_earn_assets + RCON3545 + RCON1754 + RCON1772 	if year >= 1994
replace int_earn_assets = 	int_earn_assets + RCON1350 							if year < 2002
replace int_earn_assets = 	int_earn_assets + RCONB987 + RCONB989 				if year >= 2002
label var int_earn_assets 	"Interest-Earning Assets"

gen maturity_assets 	=   (RCONA549*1.5 + RCONA550*7.5 + RCONA551 * 24 + RCONA552 * 48 + RCONA553 * 120 + RCONA554 * 240) + /// Repricing Debt Securities (Government Agencies)
							(RCONA555*1.5 + RCONA556*7.5 + RCONA557 * 24 + RCONA558 * 48 + RCONA559 * 120 + RCONA560 * 240) + /// Repricing Debt Securities (Mortgage Pass-through)
							(RCONA561*18  + RCONA562*60) + 																	  /// Repricing Debt Securities (Other MBS)
							(RCONA564*1.5 + RCONA565*7.5 + RCONA566 * 24 + RCONA567 * 48 + RCONA568 * 120 + RCONA569 * 240) + /// Repricing Loans & Leases (closed-end) (English Weighting)
							(RCONA570*1.5 + RCONA571*7.5 + RCONA572 * 24 + RCONA573 * 48 + RCONA574 * 120 + RCONA575 * 240)   /// Repricing Loans & Leases (Excluding closed-end) (English Weighting)
							
gen assets_covered		= 	(RCONA549+ RCONA550+ RCONA551+ RCONA552+ RCONA553+ RCONA554) + 		/// Repricing Debt Securities (Government Agencies)
							(RCONA555+ RCONA556+ RCONA557+ RCONA558+ RCONA559+ RCONA560) + 		/// Repricing Debt Securities (Mortgage Pass-through)
							(RCONA561+RCONA562) + 												/// Repricing Debt Securities (Other MBS)
							(RCONA564 + RCONA565 + RCONA566 + RCONA567 + RCONA568 + RCONA569) + /// Repricing Loans & Leases (closed-end) (English Weighting)
							(RCONA570 + RCONA571 + RCONA572 + RCONA573 + RCONA574 + RCONA575)   /// Repricing Loans & Leases (Excluding closed-end) (English Weighting)

gen maturity_liab_2016 	=   (RCONA584*1.5 + RCONA585*7.5 + RCONA586 * 24 + RCONA587 * 60) + 	/// Maturity and Repricing for Time Deposits > 100k
							(RCONA579*1.5 + RCONA580*7.5 + RCONA581 * 24 + RCONA582 * 60)   	/// Maturity and Repricing for Time Deposits < 100k
									
gen liab_covered_2016 	= 	((RCONA584 + RCONA585 + RCONA586 + RCONA587) + 						/// Maturity and Repricing for Time Deposit > 100k
							 (RCONA579 + RCONA580 + RCONA581 + RCONA582))  						/// Maturity and Repricing for Time Deposits < 100k

gen maturity_liab_2017  = 	((RCONHK12*1.5 + RCONHK13*7.5 + RCONHK14 * 24 + RCONHK15 * 60) + 	/// Maturity and Repricing for Time Deposits > 250k
							 (RCONHK07*1.5 + RCONHK08*7.5 + RCONHK09 * 24 + RCONHK10 * 60))  	/// Maturity and Repricing for Time Deposits < 250k
									
gen liab_covered_2017 	=	((RCONHK12 + RCONHK13 + RCONHK14 + RCONHK15) + 						/// Maturity and Repricing for Time Deposits > 250k
							 (RCONHK07 + RCONHK08 + RCONHK09 + RCONHK10))  						/// Maturity and Repricing for Time Deposits < 250k
							
gen maturity_liab 			= maturity_liab_2016
replace maturity_liab 	 	= maturity_liab_2017 if year >= 2017 
gen liab_covered 			= liab_covered_2016
replace liab_covered 		= liab_covered_2017 if year >= 2017

gen maturity_gap 			= ((maturity_assets/assets_covered)-(maturity_liab/liab_covered))/12
label var maturity_gap  	"Maturity Gap (Covered Assets and Liabilities)"

gen maturity_gap_total  	 = ((maturity_assets/RCON2170)-(maturity_liab/RCON2948))/12 // if assets_covered != 0 & liab_covered != 0
replace maturity_gap_total   = . if date<=148	// turn zeros into missings before 1997 Q2
label var maturity_gap_total "Maturity Gap (Total Assets and Liabilities)"

gen maturity_gap_int  	 	 = ((maturity_assets/int_earn_assets)-(maturity_liab/RCON2948))/12 // if assets_covered != 0 & liab_covered != 0
replace maturity_gap_int     = . if date<=148  // turn zeros into missings before 1997 Q2
label var maturity_gap_int 	"Maturity Gap (Int. Earn. Assets and Total Liabilities)"

gen assets_1y 				= RCONA549 + RCONA550 + RCONA555 + RCONA556 + RCONA564 + RCONA565 + RCONA570 + RCONA571
gen liab_2016_1y 			= RCONA579 + RCONA580 + RCONA584 + RCONA585		
gen liab_2017_1y 			= RCONHK07 + RCONHK08 + RCONHK12 + RCONHK13
gen liab_1y 				= liab_2016_1y
replace liab_1y 			= liab_2017_1y 								if year >= 2017

gen income_gap_CR 	 		= (assets_1y-liab_1y)/RCON2170 // if assets_1y != 0 & liab_1y != 0
replace income_gap_CR 		= . if date<=148  // turn zeros into missings before 1997 Q2
label var income_gap_CR  	"Income Gap based on Call Reports, next year"

gen assets_1_3y 			= RCONA551 + RCONA557 + RCONA566 + RCONA572
gen liab_2016_1_3y 			= RCONA581 + RCONA586
gen liab_2017_1_3y 			= RCONHK09 + RCONHK14
gen liab_1_3y 				= liab_2016_1_3y
replace liab_1_3y 			= liab_2017_1_3y 							if year >= 2017

gen income_gap_CR_1_3y 	 		= (assets_1_3y-liab_1_3y)/RCON2170 // if assets_1_3y != 0 & liab_1_3y != 0
replace income_gap_CR_1_3y 		= . if date<=148  // turn zeros into missings before 1997 Q2
label var income_gap_CR_1_3y  	"Income Gap based on Call Reports, 1-3 years"

gen assets_3y 				= RCONA552 + RCONA553 + RCONA554 + RCONA558 + RCONA559 + RCONA560 + RCONA562 + RCONA567 + RCONA568 + RCONA569 + RCONA573 + RCONA574 + RCONA575
gen liab_2016_3y 			= RCONA582 + RCONA587
gen liab_2017_3y 			= RCONHK10 + RCONHK15
gen liab_3y 				= liab_2016_3y
replace liab_3y 			= liab_2017_3y 								if year >= 2017

gen income_gap_CR_3y 	 	= (assets_3y-liab_3y)/RCON2170 // if assets_3y != 0 & liab_3y != 0
replace income_gap_CR_3y 	= . if date<=148  // turn zeros into missings before 1997 Q2
label var income_gap_CR_3y  "Income Gap based on Call Reports, >3 years"

preserve
	keep if year >= 1994 & year <= 2007
	
	gen test_mat_assets = (maturity_assets/assets_covered)/12
	gen test_mat_liabs  = (maturity_liab/RCON2948)/12

	sum test_mat_assets test_mat_liabs, de

restore

**********************************
* Step 6: Define Other Variables *
**********************************

* Other Assets (relative to interesting-earning assets)
gen other_assets_int 		= (int_earn_assets - assets_covered)/int_earn_assets
label var other_assets_int 	"Other Assets/Interest-Earning Assets"

* Other Assets (relative to total assets)
gen other_assets_total 			= (RCON2170 - assets_covered)/RCON2170
label var other_assets_total 	"Other Assets/Total Assets"

* Other Liabilities
gen other_liab 			= (RCON2948 - liab_covered)/RCON2948
label var other_liab 	"Other liabilities/Total Liabilities"

* Income Gap as in Gomez et al. (2016)
gen income_gap 			= (BHCK3197-(BHCK3296+BHCK3298+BHCK3408+BHCK3409))/BHCK2170
label var income_gap 	"Income Gap based on Y9C"

* Savings Deposits / Total Liabilities
gen total_savings_deposits 	= RCON6810+RCON0352
gen savings_dep_liab 		= total_savings_deposits/RCON2948
label var savings_dep_liab 	"Savings Deposits/Liabilities"

* Time Deposits / Total Liabilities
gen total_time_deposits		= RCON6648
replace total_time_deposits = total_time_deposits + RCON6645 + RCON6646 if year < 1997
replace total_time_deposits = total_time_deposits + RCON2604 			if year < 2010 & year >= 1997
replace total_time_deposits = total_time_deposits + RCONJ473 + RCONJ474 if year >= 2010
gen time_dep_liab 	    	= total_time_deposits/RCON2948
label var time_dep_liab "Time Deposits Deposits/Liabilities"

* Demand & Transaction Deposits / Total Liabilities
gen demand_dep_liab 	= RCON2215/RCON2948
label var demand_dep_liab "Demand & Transaction Deposits/Liabilities"

* Demand & Savings Deposits / Total Liabilities
gen demand_saving_dep_liab  = demand_dep_liab + savings_dep_liab
label var demand_saving_dep_liab "Demand & Savings Deposits/Liabilities"

* Deposits / Total Liablities
gen dep_liab 			= savings_dep_liab + time_dep_liab + demand_dep_liab
label var dep_liab 		"Deposits/Liabilities"

* Total Loans / Total Assets
gen loans_assets 		= RCON2122/RCON2170
label var loans_assets 	"Total Loans/Total Assets"

* Log(Real Assets)
merge m:1 date using "$input/CPI.dta"
drop if _merge == 2
drop _merge

gen logassets = log(100*RCON2170/CPI)
label var logassets "Log(Real Assets)"

gen log_risk_assets = log(100*RCONA223/CPI)
label var log_risk_assets "Log(Real Risk-weighted Assets)"

** Drop observations

if $drop_extreme_mat_gap == 1 {
	_pctile maturity_gap, percentiles(1,99)
	drop if maturity_gap <= r(r1) & maturity_gap ~= .
	drop if maturity_gap >= r(r2) & maturity_gap ~= .
}
if $drop_extreme_market_lev == 1 {
	_pctile market_lev, percentiles(1,99)
	drop if market_lev <= r(r1) & market_lev ~= .
	drop if market_lev >= r(r2) & market_lev ~= .
}
if $drop_asset_growth == 1 {
	tsset permco date
	gen asset_growth = logassets - L1.logassets
	drop if asset_growth > 0.2
	drop if asset_growth < -0.2
}
if $drop_few_observations == 1 {
	bysort permco: egen number_obser=count(_N)
	drop if number_obser < 28
}

* Save Data for NIM
if "$method"=="RESTRICTED" {
	save "$output/master_data_restricted_NIM.dta", replace
}
if "$method"=="UNRESTRICTED" {
	save "$output/master_data_unrestricted_NIM.dta", replace
}

***********************
* Step 7: Save Output *
***********************

** Save data for maturity gap plot

preserve

	collapse (mean) mean_mg=maturity_gap (p5) p5_mg=maturity_gap (p33) p33_mg=maturity_gap (p50) p50_mg=maturity_gap (p66) p66_mg=maturity_gap (p95) p95_mg=maturity_gap, by(date)
	save "$output/mat_data.dta", replace
	
restore

** Save data for income gap plot

preserve

	collapse (mean) income_gap income_gap_CR, by(date)
	save "$output/inc_gap_data.dta", replace
	
restore

** Prepare for merging with FOMC dates

* shift date forward 1 quarter
replace date = date + 1

sort 	permco date
keep 	permco date maturity_gap maturity_gap_total maturity_gap_int income_gap income_gap_CR income_gap_CR_1_3y income_gap_CR_3y loans_assets logassets log_risk_assets other_assets* other_liab savings_dep_liab time_dep_liab demand_dep_liab demand_saving_dep_liab dep_liab market_lev int_earn_assets bank_type
order 	permco date maturity_gap maturity_gap_total maturity_gap_int income_gap income_gap_CR income_gap_CR_1_3y income_gap_CR_3y loans_assets logassets log_risk_assets other_assets* other_liab savings_dep_liab time_dep_liab demand_dep_liab demand_saving_dep_liab dep_liab market_lev int_earn_assets bank_type

duplicates report date permco

rename date date2

* Save Data for Even Window Analysis
if "$method"=="RESTRICTED" {
	save "$output/master_data_restricted.dta", replace
}
if "$method"=="UNRESTRICTED" {
	save "$output/master_data_unrestricted.dta", replace
}
